@@ -1,5 +1,5 @@
 # Copyright (c) 2011 by Gentoo Foundation
-# All rights reserved. Released under the 2-clause BSD license.
+# Released under the 2-clause BSD license.
 
 _ethtool() {
 	echo /usr/sbin/ethtool
@@ -25,11 +25,11 @@ ethtool_pre_start() {
 	eindent
 	for opt in ${order} ; do
 		local args
-		eval args=\$ethtool_${opt//-/_}_${IFVAR}
+		eval args=\$ethtool_$(echo $opt | tr - _)_${IFVAR}
 
 		# Skip everything if no arguments
 		[ -z "${args}" ] && continue
-		
+
 		# Split on \n
 		local IFS="$__IFS"
 
@@ -37,7 +37,7 @@ ethtool_pre_start() {
 			IFS="${OIFS}"
 			local args_pretty="$(_trim "${p}")"
 			# Do nothing if empty
-			[ -z "${args_prety}" ] && continue
+			[ -z "${args_pretty}" ] && continue
 			args_pretty="--${opt} $IFACE ${args_pretty}"
 			args="--${opt} $IFACE ${args}"
 			ebegin "ethtool ${args_pretty}"
